pub enum DeviceSinkError {
PlayError(PlayStreamError),
DefaultSinkConfigError(DefaultStreamConfigError),
BuildError(BuildStreamError),
SupportedConfigsError(SupportedStreamConfigsError),
NoDevice,
UnsupportedSampleFormat,
}Expand description
Errors that might occur when interfacing with audio output.
Variants
PlayError(PlayStreamError)
Could not start playing the sink, see cpal::PlayStreamError for details.
DefaultSinkConfigError(DefaultStreamConfigError)
Failed to get the stream config for the given device. See cpal::DefaultStreamConfigError for details.
BuildError(BuildStreamError)
Error opening sink with OS. See cpal::BuildStreamError for details.
SupportedConfigsError(SupportedStreamConfigsError)
Could not list supported configs for the device. Maybe it disconnected. For details see: cpal::SupportedStreamConfigsError.
NoDevice
Could not find any output device
UnsupportedSampleFormat
New cpal sample format that rodio does not yet support please open an issue if you run into this.